#ifndef _COMMON_H
#define _COMMON_H
#define BUFSIZE		8192
#define LIST_MINSIZE	6
#define LIST_SPACEPOS   5

/* signal.c */
void got_sig(int);
#endif /* COMMON_H */
